@@ -1,10 +1,7 @@
 # -*- coding: utf-8 -*-
 
-from concurrent.futures import Future
 from typing import Any
 
-from pip_services3_grpc.protos.commandable_pb2 import InvokeRequest
-
 from pip_services3_grpc.clients.GrpcClient import GrpcClient
 
 
